@@ -37,7 +37,7 @@ class channel(Init):
        
             self.channel=self.channellink
             c=Crawl(video_link=self.channel)
-            self.chanid=await c.videolink().split("/")[-1]
+            self.chanid=(await c.videolink()).split("/")[-1]
         elif self.channelname:
             soup =await  self.init("https://www.youtube.com/results?search_query=" + self.channelname)
             self.channel=soup.find("a",{"class":"channel-link yt-simple-endpoint style-scope ytd-channel-renderer"}).get("href")
