@@ -28,11 +28,8 @@ class channel:
         elif channellink:
             self.channel=channellink
         elif channelname:
-            if " " in channelname:
-                channelname=channelname.split()
-                channelname="+".join(channelname)
             response = self.session.get("https://www.youtube.com/results?search_query=" + channelname)
-            response.html.render(sleep=1,keep_page=True,timeout=30)
+            response.html.render(sleep=1)
             
             soup = BeautifulSoup(response.html.html, "html.parser") 
             self.channel=soup.find("a",{"class":"channel-link yt-simple-endpoint style-scope ytd-channel-renderer"}).get("href")
@@ -41,19 +38,18 @@ class channel:
         else:
             raise ValueError("No Paramter is provided")
         response = self.session.get(self.channel)
-        response.html.render(sleep=1,keep_page=True,timeout=30)
+        response.html.render(sleep=1)
         self.soup = BeautifulSoup(response.html.html, "html.parser") 
         
-        response.session.close()
+        
     def subs(self):
             return self.soup.find("yt-formatted-string",{"id":"subscriber-count"}).text
      
     
     def about(self):
         response = self.session.get('https://www.youtube.com' + self.id + "/" + "about")
-        response.html.render(sleep=1,keep_page=True,timeout=30)
+        response.html.render(sleep=1)
         soup = BeautifulSoup(response.html.html, "html.parser")  
-        response.session.close()
         return soup
 
     def description(self):
@@ -87,9 +83,8 @@ class channel:
                  
                  session=HTMLSession()
                  response = session.get(x)
-                 response.html.render(sleep=1,keep_page=True,timeout=30)
+                 response.html.render(sleep=1)
                  x = BeautifulSoup(response.html.html, "html.parser")  
-                 response.session.close()
                  x=x.find_all("div",attrs={"id":"redirect-action-container"})
                  for i in x:
                      x=i.find("a")['href']
@@ -106,33 +101,28 @@ class channel:
     def latest_video(self):
      print('https://www.youtube.com' + self.id + "/" + "videos")
      response = self.session.get('https://www.youtube.com' + self.id + "/" + "videos")
-     response.html.render(sleep=1,keep_page=True,timeout=30)
+     response.html.render(sleep=1)
      soup = BeautifulSoup(response.html.html, "html.parser")  
      op=soup.find("a",{"id":"thumbnail"}).get('href')
-     response.session.close()
      op=crawl(video_link="https://www.youtube.com" + op)
      return {"Latest Video" : op.VideoDetails()}
     
     def latest_community(self):
      response = self.session.get('https://www.youtube.com' + self.id + "/" + "community")
-     response.html.render(sleep=1,keep_page=True,timeout=30)
+     response.html.render(sleep=1)
      soup = BeautifulSoup(response.html.html, "html.parser")  
      comun=soup.find("yt-formatted-string",{"id":"content-text"}).text
-     response.session.close()
      return comun
  
     def spareChannels(self):
       session=HTMLSession()
       response = session.get('https://www.youtube.com' + self.id + "/" + "channels")
-      response.html.render(sleep=1,keep_page=True,timeout=30)
-    
+      response.html.render(sleep=1)
       soup = BeautifulSoup(response.html.html, "html.parser")
-      response.session.close()
       channels={}
       for i in soup.find_all("div",{"id":"channel"}):
            response = session.get('https://www.youtube.com' + i.find("a")['href'])
-           response.html.render(sleep=1,keep_page=True,timeout=30)
+           response.html.render(sleep=1)
            soup = BeautifulSoup(response.html.html, "html.parser")
            channels.update({i.find('span').text:{"Link":'https://www.youtube.com' + i.find("a")['href'],"Subscribers":soup.find("yt-formatted-string",{"id":"subscriber-count"}).text }})
-      response.session.close()
       return channels
